@@ -14,7 +14,7 @@ use CPAN::Testers::Common::Client::History;
 
 use constant MAX_OUTPUT_LENGTH => 1_000_000;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 
 #==================================
@@ -407,26 +407,26 @@ sub _format_prereq_report {
 sub _get_env_vars {
     # Entries bracketed with "/" are taken to be a regex; otherwise literal
     my @env_vars= qw(
-        /PERL/
+        /HARNESS/
         /LC_/
-        /AUTHOR_TEST/
-        /RELEASE_TEST/
+        /PERL/
+        /_TEST/
+        CCFLAGS
+        COMSPEC
+        INCLUDE
         LANG
         LANGUAGE
+        LD_LIBRARY_PATH
+        LDFLAGS
+        LIB
+        NUMBER_OF_PROCESSORS
         PATH
+        PROCESSOR_IDENTIFIER
         SHELL
-        COMSPEC
         TERM
         TEMP
         TMPDIR
-        AUTOMATED_TESTING
         NON_INTERACTIVE
-        EXTENDED_TESTING
-        INCLUDE
-        LIB
-        LD_LIBRARY_PATH
-        PROCESSOR_IDENTIFIER
-        NUMBER_OF_PROCESSORS
     );
 
     my %env_found = ();
@@ -839,6 +839,9 @@ If the C<AUTOMATED_TESTING> environment variable is set to true, the default com
 
 Otherwise, the default message is C<'none provided'>.
 
+CPAN::Testers::Common::Client::Config also has
+L<< some interesting environment variables|CPAN::Testers::Common::Client::Config/"CONFIGURATION AND ENVIRONMENT" >>.
+
 =head2 Source Code
 
 This is open source software.  The code repository is available for
